# foxglove

[![CI](https://github.com/samuelcolvin/foxglove/workflows/CI/badge.svg?event=push)](https://github.com/samuelcolvin/foxglove/actions?query=event%3Apush+branch%3Amaster+workflow%3ACI)
[![Coverage](https://codecov.io/gh/samuelcolvin/foxglove/branch/master/graph/badge.svg)](https://codecov.io/gh/samuelcolvin/foxglove)
[![pypi](https://img.shields.io/pypi/v/foxglove-web.svg)](https://pypi.python.org/pypi/foxglove-web)
[![versions](https://img.shields.io/pypi/pyversions/foxglove-web.svg)](https://github.com/samuelcolvin/foxglove)
[![license](https://img.shields.io/github/license/samuelcolvin/foxglove.svg)](https://github.com/samuelcolvin/foxglove/blob/master/LICENSE)
